ngff_zarr.ngff_image_to_itk_image - ngff-zarr
Description: Module Contents: Functions:,,_dtype_to_component_type,,, ngff_image_to_itk_image,,,,, API:

Hide navigation sidebar
Hide table of contents sidebar
Skip to content
Back to top
View this page
Edit this page
Toggle table of contents sidebar

# `ngff_zarr.ngff_image_to_itk_image`

## Module Contents

### Functions

`_dtype_to_component_type` |
`ngff_image_to_itk_image` |

### API

ngff_zarr.ngff_image_to_itk_image._dtype_to_component_type(dtype)

ngff_zarr.ngff_image_to_itk_image.ngff_image_to_itk_image(ngff_image: ngff_zarr.ngff_image.NgffImage, wasm: bool = True)